.. _explanations:

==============
 Explanations
==============


Explanations provide in-depth discussions about select SymPy features. These
topic guides talk about things like the motivation behind design decisions,
technical implementation details, and opinionated recommendations.

**Content**

.. toctree::
   :maxdepth: 1

   gotchas.rst
   solve_output.rst
   special_topics/index.rst
   active-deprecations.md
   glossary.md
